﻿using System.Collections.ObjectModel;
using System.Windows;
using System.Windows.Input;
using System;
using Infragistics.Controls.Menus;
using System.Collections.Generic;
using System.Windows.Controls;

using System.Linq;
using System.Text;


using System.Windows.Data;
using System.Windows.Documents;

using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

using System.Diagnostics;

namespace TestTreeView
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        #region Properties
        public ObservableCollection<TestClass> Children { get; set; }

        private int newCount = 0; 
        #endregion

        #region Constructor
        public MainWindow()
        {
            Children = new ObservableCollection<TestClass>();
            Children.Add(new TestClass(5,1));
            this.DataContext = this;

            InitializeComponent();

            treeViewTest.MouseRightButtonDown += new MouseButtonEventHandler(treeViewTest_MouseRightButtonDown);
            treeViewTest.InitializeNode += new EventHandler<InitializeNodeEventArgs>(treeViewTest_InitializeNode);
        } 
        #endregion

        #region Methods
        private void SelectNode(string nodePath)
        {
            if (!string.IsNullOrEmpty(nodePath))
            {
                SelectNode(new List<string>(nodePath.Split('\\')));
            }
        }
        private void SelectNode(List<string> nodePathList)
        {
            if (nodePathList.Count > 0)
            {
                var targetName = nodePathList[0];
                nodePathList.RemoveAt(0);

                // Find the target node
                var qNode = from n in Children where n.Name == targetName select n;
                if (qNode.Count() > 0)
                {
                    var node = qNode.First();

                    node.SelectNode(nodePathList);
                } 
            }
        }
        #endregion

        #region Events
        void treeViewTest_InitializeNode(object sender, InitializeNodeEventArgs e)
        {
            var view = e.Node.Data as TestClass;
            if (view != null)
            {
                view.XamNode = e.Node;
            }
        }

        void treeViewTest_MouseRightButtonDown(object sender, MouseButtonEventArgs e)
        {
            var nodeContext = (e.OriginalSource as FrameworkElement).DataContext as XamDataTreeNodeDataContext;
            if (nodeContext != null)
            {
                var node = nodeContext.Node;
                if (node != null)
                {
                    treeViewTest.ActiveNode = node;
                    node.IsActive = true;
                    node.IsSelected = true;
                }
            }
        }

        private void mnuItemNew_Click(object sender, RoutedEventArgs e)
        {
            var selectedItem = treeViewTest.ActiveNode;
            if (selectedItem != null)
            {
                var data = selectedItem.Data as TestClass;

                data.Children.Add(new TestClass(string.Format("New {0}", ++newCount)));

                data.IsExpanded = true;
            }
        }

        private void txtSelectedPath_TextChanged(object sender, TextChangedEventArgs e)
        {
            SelectNode(txtSelectedPath.Text);
        }
        #endregion

    }
}
